@@ -24,13 +24,11 @@
 
 #include <cstdlib>		// Provides size_t and NULL
 #include <iostream>
-#include <string>
 #include <map>
 #include <memory>
 
 // types.h should be first user-defined header.
 #include "smbios/types.h"
-
 #include "smbios/IFactory.h"
 #include "smbios/IException.h"
 #include "smbios/SmbiosLowLevel.h"
@@ -46,6 +44,8 @@ namespace smbios
     DECLARE_EXCEPTION_EX( ParseException, smbios, SmbiosException );
     DECLARE_EXCEPTION_EX( StringUnavailable, smbios, SmbiosException );
     DECLARE_EXCEPTION_EX( DataOutOfBounds, smbios, SmbiosException );
+    DECLARE_EXCEPTION_EX( ItemNotFound, smbios, SmbiosException );
+
 
     //forward declarations... defined 'for real' below...
     class ISmbiosTable;
@@ -170,11 +170,6 @@ namespace smbios
 smbios::ISmbiosTable *table = smbios::SmbiosFactory::getFactory()->getSingleton();
 smbios::ISmbiosTable::iterator item1 = (*table)[0];
 cout << "The BIOS Version is: " << item1->getString(0x05) << endl;
-
-// XML string indexing example
-smbios::ISmbiosTable *table = smbios::SmbiosXmlFactory::getFactory()->getSingleton();
-smbios::ISmbiosTable::iterator item1 = (*table)["BIOS Information"];
-cout << "The BIOS Version is: " << item1->getString("BIOS Version") << endl;
 \endcode
          * \sa operator[]( const std::string & ) const
          */
@@ -184,25 +179,6 @@ cout << "The BIOS Version is: " << item1->getString("BIOS Version") << endl;
          /** \copydoc operator[]( const int ) */
         virtual const_iterator operator[]( const int ) const = 0;
 
-        //! Standard indexed access by string description. XML ENHANCED.
-        /** XML Enhanced indexing operator. You can pass in a string description
-         * of the table and the SmbiosTable class will look up the string in an
-         * XML description file to find out the item number that corresponds
-         * with that text.
-         *
-         * The nice extension that is supplied by the XML interface is that all
-         * Item access to the item returned are type checked against the XML, so
-         * you cannot, for example, access an 8-bit number as a 16-bit number.
-         *
-         * \copydoc operator[](const int)
-         * \sa operator[]( const int )
-         */
-        virtual iterator operator[]( const std::string & ) = 0;
-
-        //! Standard indexed access by string description. XML ENHANCED.
-         /** \copydoc operator[]( const std::string & ) */
-        virtual const_iterator operator[]( const std::string & ) const = 0;
-
         // MEMBERS
         //! Disables all workarounds for _new_ items created by the table.
         /** Any new item generated by the table will not have workarounds
@@ -233,35 +209,25 @@ cout << "The BIOS Version is: " << item1->getString("BIOS Version") << endl;
          */
         virtual void clearItemCache() const = 0;  
 
-        //! Re-Read the table from memory. Invalidates all existing ISmbiosItems
-        /** <b>Not yet implemented</b>
-         * This API is intended to be used in the instance where SMBIOS data is
-         * not static, ie. BIOS updates SMBIOS information while the system is
-         * running.
-         *
-         * Most systems have static tables that do not change after the system
-         * boots. Systems have been proposed to update this information at
-         * runtime inside system SMI calls. This API is put into place to
-         * prepare for this possibility.
-         * 
-         * \warning All previous references or pointers to ISmbiosItem objects
-         * created from this table become invalid and attempts to access them
-         * will cause undefined behaviour (most likely your code will crash.)
-         */
-        virtual void reReadTable() = 0;
-
         //! Returns the number of table items, per SMBIOS table header
         virtual int getNumberOfEntries () const = 0;  // used by unit-test code
         //! Returns  the table entry point structure
         // Used by the validateBios code.
         virtual smbiosLowlevel::smbios_table_entry_point getTableEPS() const = 0;
 
+        friend class SmbiosTableIteratorBase;
+    protected:
+        virtual const ISmbiosItem & getSmbiosItem (const u8 *current) const = 0;
+        virtual ISmbiosItem & getSmbiosItem (const u8 *current) = 0;
+        virtual const u8 * nextSmbiosStruct ( const u8 * current = 0) const = 0;
+
         //! Used by operator << (std::ostream & cout, const ISmbiosTable & ) to
         //output table information.
         /** Users normally would not need or want to call this API. The normal
          * operator<<() has been overloaded to call this function internally.
          */
         virtual std::ostream & streamify(std::ostream & cout ) const = 0;
+        friend std::ostream & operator << (std::ostream & cout, const ISmbiosTable & item);
 
     private:
         explicit ISmbiosTable(const ISmbiosTable &); ///< not implemented (explicitly disallowed)
@@ -282,13 +248,6 @@ cout << "The BIOS Version is: " << item1->getString("BIOS Version") << endl;
         virtual std::auto_ptr<const ISmbiosItem> clone() const = 0;
         virtual std::auto_ptr<ISmbiosItem> clone() = 0;
 
-        /** Used by 'std::ostream &smbios::operator <<( std::ostream &, ISmbiosItem&)'
-         * to print out the item info.
-         *
-         * Not particularly useful for clients. Use operator<< instead.
-         */
-        virtual std::ostream & streamify( std::ostream & cout ) const = 0;
-
         /** Returns the Type field of the SMBIOS Item.
          * This field is standard for all SMBIOS tables and is defined
          * in the SMBIOS standard.
@@ -334,17 +293,13 @@ cout << "The BIOS Version is: " << item1->getString("BIOS Version") << endl;
          * that (for example) when you use getU8() that the location you are 
          * trying to access is actually a U8. 
          */
+        virtual void getData( unsigned int offset, u8 *out, size_t size ) const = 0;
 
-        virtual void getData( unsigned int offset, void *out, size_t size ) const = 0;
-
-        //loathe Stroustrup. In his infinite wisdom, he asserts that
-        //auto_ptr equivalent for array is _not_necessary_.
-        //Here would be a good place for one. :-(
         virtual const u8* getBufferCopy(size_t &length) const = 0;
         
         //! Returns the buffer size of the item.
         // The validateBios.cpp calls this function.
-        virtual const size_t getBufferSize() const = 0;
+        virtual size_t getBufferSize() const = 0;
 
         /** Not likely to be useful to regular client code. It is public
          * mainly to help in writing Unit Tests. Clients should normally 
@@ -358,6 +313,15 @@ cout << "The BIOS Version is: " << item1->getString("BIOS Version") << endl;
             FIELD_LEN_DWORD=4,
             FIELD_LEN_QWORD=8
         };
+
+    protected:
+        /** Used by 'std::ostream &smbios::operator <<( std::ostream &, ISmbiosItem&)'
+         * to print out the item info.
+         *
+         * Not particularly useful for clients. Use operator<< instead.
+         */
+        virtual std::ostream & streamify( std::ostream & cout ) const = 0;
+        friend std::ostream & operator << (std::ostream & cout, const ISmbiosItem & item);
     };
 
     u8 getItemType(const ISmbiosItem &item);
@@ -379,7 +343,6 @@ cout << "The BIOS Version is: " << item1->getString("BIOS Version") << endl;
         return out;
     }
 
-
     //! Iterator base class for ISmbiosTable objects.
     /** The base class for iterators over ISmbiosTable. This class has all of
      * the data items to keep track of the position. There is no good way to
@@ -388,93 +351,67 @@ cout << "The BIOS Version is: " << item1->getString("BIOS Version") << endl;
      *
      * This class is stable and should not be modified.
      */
-    class SmbiosTableIteratorBase : 
+    class SmbiosTableIteratorBase
+    {
+    public:
+        typedef std::forward_iterator_tag iterator_category;
+        typedef std::ptrdiff_t difference_type;
+
+
+        explicit SmbiosTableIteratorBase(const ISmbiosTable * initialTable = 0, int typeToMatch = -1 );
+        SmbiosTableIteratorBase &operator=(const SmbiosTableIteratorBase&);
+        virtual ~SmbiosTableIteratorBase() throw();
+        bool operator == (const SmbiosTableIteratorBase &other) const;
+        bool operator != (const SmbiosTableIteratorBase &other) const;
+        void incrementIterator ();
+        const ISmbiosItem & dereference () const;
+        ISmbiosItem & dereference ();
+
+        void reset();
+        bool eof();
+
+    protected:
+        int matchType;
+        const ISmbiosTable * table;
+        const u8 * current;
+    };
+
+    class SmbiosTableIterator:
+        public SmbiosTableIteratorBase,
         public std::iterator < std::forward_iterator_tag, ISmbiosItem >
     {
     public:
-        explicit SmbiosTableIteratorBase (const ISmbiosTable * initialTable = 0, int typeToMatch = -1 )
-            : matchType(typeToMatch), table(initialTable), current(0)
-            { incrementIterator(); };
-        virtual ~SmbiosTableIteratorBase() throw() {};
-        bool operator == (const SmbiosTableIteratorBase other) const { return current == other.current; };
-        bool operator != (const SmbiosTableIteratorBase other) const { return current != other.current; };
-
-    protected:
-        void incrementIterator ();
-        ISmbiosItem & dereference () const;
-
-        int matchType;
-        const ISmbiosTable * table;
-        mutable const void * current;
-    };
-    
-    //! Iterator for ISmbiosTable objects.
-    /** In order to properly enforce difference between iterator and
-     * const_iterator, we need to derive them both separately from the base
-     * iterator class. the const_iterator cannot inherit from iterator, or
-     * compiler will automatically convert between the two, which is not good.
-     *
-     * This class is stable. Do not add or remove any members from it.
-     */
-    class SmbiosTableIterator
-        : public SmbiosTableIteratorBase
-    {
-    public:
-        // Make sure you define these, otherwise you can't use
-        // iterators in stl algorithms
-        typedef std::forward_iterator_tag iterator_category;
         typedef ISmbiosItem value_type;
         typedef value_type& reference;
         typedef value_type* pointer;
-        typedef std::ptrdiff_t difference_type;
 
-        virtual ~SmbiosTableIterator() throw() {};
-        explicit SmbiosTableIterator (ISmbiosTable * initialTable = 0, int typeToMatch = -1 )
-            : SmbiosTableIteratorBase(initialTable, typeToMatch) {};
-        reference operator * () const { return dereference(); };
-        pointer   operator -> () const { return &dereference(); };
-        SmbiosTableIterator & operator ++ () { incrementIterator(); return *this; }; // ++Prefix
-        const SmbiosTableIterator operator ++ (int)     
-        {
-            const SmbiosTableIterator oldValue = *this;
-            ++(*this);
-            return oldValue;
-        };  //Postfix++
+        virtual ~SmbiosTableIterator() throw();
+        explicit SmbiosTableIterator(ISmbiosTable * initialTable = 0, int typeToMatch = -1 );
+        reference operator * ();
+        pointer   operator -> ();
+        SmbiosTableIterator & operator ++ (); // ++Prefix
+        const SmbiosTableIterator operator ++ (int);  //Postfix++
     };
 
-    //! Iterator for const ISmbiosTable objects.
-    /** In order to properly enforce difference between iterator and
-     * const_iterator, we need to derive them both separately from the base
-     * iterator class. the const_iterator cannot inherit from iterator, or
-     * compiler will automatically convert between the two, which is not good.
-     *
-     * This class is stable. Do not add or remove any members from it.
-     */
-    class ConstSmbiosTableIterator:public SmbiosTableIteratorBase
+    class ConstSmbiosTableIterator:
+        public SmbiosTableIteratorBase,
+        public std::iterator < std::forward_iterator_tag, const ISmbiosItem >
     {
     public:
-        // Make sure you define these, otherwise you can't use
-        // iterators in stl algorithms
-        typedef std::forward_iterator_tag iterator_category;
         typedef const ISmbiosItem value_type;
         typedef value_type& reference;
         typedef value_type* pointer;
-        typedef std::ptrdiff_t difference_type;
 
-        virtual ~ConstSmbiosTableIterator() throw() {};
-        explicit ConstSmbiosTableIterator (const ISmbiosTable * initialTable = 0, int typeToMatch = -1 )
-            : SmbiosTableIteratorBase(initialTable, typeToMatch) {};
-        reference operator * () const { return dereference(); };
-        pointer   operator -> () const { return &dereference(); };
-        ConstSmbiosTableIterator & operator ++ () { incrementIterator(); return *this; };	      // ++Prefix
-        const ConstSmbiosTableIterator operator ++ (int)
-        {
-            const ConstSmbiosTableIterator oldValue = *this;
-            ++(*this);
-            return oldValue;
-        };  //Postfix++
+        virtual ~ConstSmbiosTableIterator() throw();
+        explicit ConstSmbiosTableIterator(const ISmbiosTable * initialTable = 0, int typeToMatch = -1 );
+        ConstSmbiosTableIterator &operator=(const SmbiosTableIteratorBase&);
+
+        reference operator * () const;
+        pointer   operator -> () const;
+        ConstSmbiosTableIterator & operator ++ (); // ++Prefix
+        const ConstSmbiosTableIterator operator ++ (int);  //Postfix++
     };
-
+    
     //
     // Non-member functions
     //
