@@ -104,10 +104,10 @@ namespace smbios
         GetSystemFirmwareTable( iSignature, 0, newSmbiosBuffer, iBufferSizeNeeded );
 
         // Have to manually set values in header because we cannot get table entry point using this api
-        table_header->table_length = static_cast<u16>(iBufferSizeNeeded);
+        table_header->dmi.table_length = static_cast<u16>(iBufferSizeNeeded);
         table_header->major_ver = newSmbiosBuffer[1];
         table_header->minor_ver = newSmbiosBuffer[2];
-        table_header->table_num_structs = 9999;
+        table_header->dmi.table_num_structs = 9999;
 
         // get rid of header that MS tacks on.
 #       define MS_RSMB_HEADER_SIZE 8
@@ -286,10 +286,10 @@ namespace smbios
             throw ParseExceptionImpl( _("getSmbiosTable(): GetWMISMBIOSData returned 0 for buffer size.") );
 
         // fake version information for now.
-        table_header->table_length = static_cast<u16>(wmi_smbiosData.bufferSize);
+        table_header->dmi.table_length = static_cast<u16>(wmi_smbiosData.bufferSize);
         table_header->major_ver = wmi_smbiosData.majorVersion;
         table_header->minor_ver = wmi_smbiosData.minorVersion;
-        table_header->table_num_structs = 9999;
+        table_header->dmi.table_num_structs = 9999;
 
         //delete old one, if necessary
         if( *smbiosBuffer )
