@@ -17,6 +17,10 @@
  */
 
 #define LIBSMBIOS_SOURCE
+#include "smbios/compat.h"
+
+#include <string.h>
+
 #include "smbios/ISmbios.h"
 #include "smbios/IToken.h"
 
@@ -120,8 +124,8 @@ static u16 getIdByteFromOEMItem ()
 {
     //functionEnter( "%s", "" );
     u16 idWord = 0;
-    smbios::ISmbiosTable *table = 0;
-    smbios::ISmbiosTable::iterator item;
+    const smbios::ISmbiosTable *table = 0;
+    smbios::ISmbiosTable::const_iterator item;
     if (!couldBeBayonet())
         goto out;
 
@@ -152,8 +156,8 @@ static u16 getIdByteFromRevItem ()
 {
     //functionEnter( "%s", "" );
     u16 idWord = 0;
-    smbios::ISmbiosTable *table = 0;
-    smbios::ISmbiosTable::iterator item;
+    const smbios::ISmbiosTable *table = 0;
+    smbios::ISmbiosTable::const_iterator item;
 
     table = smbios::SmbiosFactory::getFactory()->getSingleton();
 
