@@ -17,6 +17,10 @@
  */
 
 #define LIBSMBIOS_SOURCE
+#include "smbios/compat.h"
+
+#include <string.h>
+
 #include "smbios/ISmbios.h"
 #include "smbios/IToken.h"
 #include "smbios/ISmi.h"
@@ -237,7 +241,7 @@ static void setTagUsingSMI(const char *newTag, u16 select)
 
 static char *getStringFromTable(unsigned int structure, unsigned int stringNumber)
 {
-    smbios::ISmbiosTable *table = 0;
+    const smbios::ISmbiosTable *table = 0;
     table = smbios::SmbiosFactory::getFactory()->getSingleton();
 
     if (!table)
