@@ -30,6 +30,8 @@
 // all our magic numbers
 #include "DellMagic.h"
 
+#include <string.h>
+
 // include this last.
 #include "smbios/message.h"
 
@@ -62,11 +64,11 @@ bool couldBeBayonet ()
     //functionEnter( "%s", "" );
     bool couldBeBayonet = false;
 
-    smbios::ISmbiosTable *table =
+    const smbios::ISmbiosTable *table =
         smbios::SmbiosFactory::getFactory()->getSingleton();
 
     // crappy msvc compiler workaround
-    smbios::ISmbiosTable::iterator item ;
+    smbios::ISmbiosTable::const_iterator item ;
 
     if (0 == table)
         throw InternalErrorImpl();
